==> dirigible-api-javascript-io-3.1.1-sources.jar: io/v3/files.js <==
/*
 * Copyright (c) 2017 SAP and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * Contributors:
 * SAP - initial API and implementation
 */

var java = require('core/v3/java');
var streams = require("io/v3/streams");

   
exports.exists = function(path){
  	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "exists", [path]);
}
    
exports.isExecutable = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isExecutable", [path]);
};

exports.isReadable = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isReadable", [path]);
};

exports.isWritable = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isWritable", [path]);
};

exports.isHidden = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isHidden", [path]);
};

exports.isDirectory = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isDirectory", [path]);
};

exports.isFile = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isFile", [path]);
};

exports.isSameFile = function(path1, path2) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isSameFile", [path1, path2]);
};


exports.getCanonicalPath = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getCanonicalPath", [path]);
};

exports.getName = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getName", [path]);
};

exports.getParentPath = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getParentPath", [path]);
};

exports.readBytes = function(path){
    var result = java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "readBytes", [path]);
    var bytes = JSON.parse(result);
    return bytes;
}

exports.readText = function(path){
    return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "readText", [path]);
}

exports.writeBytes = function(path, bytes){
    java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "writeBytes", [path, JSON.stringify(bytes)]);
}

exports.writeText = function(path, text){
    java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "writeText", [path, text]);
}

exports.getLastModified = function(path) {
   	return new Date(java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getLastModified", [path]));
};

exports.setLastModified = function(path, time) {
   	java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "setLastModified", [path, time.getMilliseconds()]);
};

exports.getOwner = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getOwner", [path]);
};

exports.setOwner = function(path, owner) {
   	java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "setOwner", [path, owner]);
};

exports.getPermissions = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getPermissions", [path]);
};

exports.setPermissions = function(path, permissions) {
   	java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "setPermissions", [path, permissions]);
};

exports.size = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "size", [path]);
};

exports.createFile = function(path) {
   	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createFile", [path]);
};

exports.createDirectory = function(path) {
  	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createDirectory", [path]);
};

exports.copy = function(source, target) {
 	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "copy", [path, source, target]);
};

exports.move = function(source, target) {
	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "move", [path, source, target]);
};

exports.deleteFile = function(path) {
  	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "deleteFile", [path]);
};

exports.deleteDirectory = function(path, forced) {
 	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "deleteDirectory", [path, forced]);
};

exports.createTempFile = function(prefix, suffix) {
  	 return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createTempFile", [prefix, suffix]);
};

exports.createTempDirectory = function(prefix) {
 	 return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createTempDirectory", [prefix]);
};

exports.createInputStream = function(path) {
	 var inputStreamInstance = java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createInputStream", [path], true);
	 var inputStream = new streams.InputStream();
	 inputStream.uuid = inputStreamInstance.uuid;
	 return inputStream;
};

exports.createOutputStream = function(path) {
	 var outputStreamInstance = java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createOutputStream", [path], true);
	 var outputStream = new streams.OutputStream();
	 outputStream.uuid = outputStreamInstance.uuid;
	 return outputStream;
};

==> dirigible-api-javascript-io-4.4.0-sources.jar: io/v3/files.js <==
/*
 * Copyright (c) 2010-2019 SAP and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *   SAP - initial API and implementation
 */
var java = require('core/v3/java');
var streams = require("io/v3/streams");

   
exports.exists = function(path){
  	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "exists", [path]);
}
    
exports.isExecutable = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isExecutable", [path]);
};

exports.isReadable = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isReadable", [path]);
};

exports.isWritable = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isWritable", [path]);
};

exports.isHidden = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isHidden", [path]);
};

exports.isDirectory = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isDirectory", [path]);
};

exports.isFile = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isFile", [path]);
};

exports.isSameFile = function(path1, path2) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "isSameFile", [path1, path2]);
};


exports.getCanonicalPath = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getCanonicalPath", [path]);
};

exports.getName = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getName", [path]);
};

exports.getParentPath = function(path) {
	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getParentPath", [path]);
};

exports.readBytes = function(path){
    var result = java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "readBytes", [path]);
    var bytes = JSON.parse(result);
    return bytes;
}

exports.readText = function(path){
    return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "readText", [path]);
}

exports.writeBytes = function(path, bytes){
    java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "writeBytes", [path, JSON.stringify(bytes)]);
}

exports.writeText = function(path, text){
    java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "writeText", [path, text]);
}

exports.getLastModified = function(path) {
   	return new Date(java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getLastModified", [path]));
};

exports.setLastModified = function(path, time) {
   	java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "setLastModified", [path, time.getMilliseconds()]);
};

exports.getOwner = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getOwner", [path]);
};

exports.setOwner = function(path, owner) {
   	java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "setOwner", [path, owner]);
};

exports.getPermissions = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "getPermissions", [path]);
};

exports.setPermissions = function(path, permissions) {
   	java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "setPermissions", [path, permissions]);
};

exports.size = function(path) {
   	return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "size", [path]);
};

exports.createFile = function(path) {
   	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createFile", [path]);
};

exports.createDirectory = function(path) {
  	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createDirectory", [path]);
};

exports.copy = function(source, target) {
 	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "copy", [path, source, target]);
};

exports.move = function(source, target) {
	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "move", [path, source, target]);
};

exports.deleteFile = function(path) {
  	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "deleteFile", [path]);
};

exports.deleteDirectory = function(path, forced) {
 	 java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "deleteDirectory", [path, forced]);
};

exports.createTempFile = function(prefix, suffix) {
  	 return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createTempFile", [prefix, suffix]);
};

exports.createTempDirectory = function(prefix) {
 	 return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createTempDirectory", [prefix]);
};

exports.createInputStream = function(path) {
	 var inputStreamInstance = java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createInputStream", [path], true);
	 var inputStream = new streams.InputStream();
	 inputStream.uuid = inputStreamInstance.uuid;
	 return inputStream;
};

exports.createOutputStream = function(path) {
	 var outputStreamInstance = java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "createOutputStream", [path], true);
	 var outputStream = new streams.OutputStream();
	 outputStream.uuid = outputStreamInstance.uuid;
	 return outputStream;
};

exports.traverse = function(path) {
 	 return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "traverse", [path]);
};

exports.list = function(path) {
 	 return java.call("org.eclipse.dirigible.api.v3.io.FilesFacade", "list", [path]);
};
